@@ -3,30 +3,35 @@
 //! 
 //! Cartesian coordinates store the distance of the point compared to the origin for each axis.
 //! 
-//! Support conversion to and from Spherical coordinates.
+//! Support conversion to and from Spherical and Cylindrical coordinates.
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-use std::f64::consts::PI;
-
-use std::ops::{     // Implementing basic operations
-    Add,            // Addition
-    AddAssign,      // Assigning addition
-    Sub,            // Subtraction
-    SubAssign,      // Assigning addition
-    Mul,            // Multiplication
-    MulAssign,      // Assigning multiplication
-    Div,            // Division
-    DivAssign,      // Assigning division
-    Neg             // Negation
+use std::f64::consts::{         // Using std lib constants
+    PI                          // Pi
 };
 
-use std::fmt::{     // Formatter display
-    Display,        // The display itself
-    Result as DRes  // The associated result
+use std::ops::{                 // Implementing basic operations
+    Add,                        // Addition
+    AddAssign,                  // Assigning addition
+    Sub,                        // Subtraction
+    SubAssign,                  // Assigning addition
+    Mul,                        // Multiplication
+    MulAssign,                  // Assigning multiplication
+    Div,                        // Division
+    DivAssign,                  // Assigning division
+    Neg                         // Negation
 };
 
-use super::spherical::Spherical;
+use std::fmt::{                 // Formatter display
+    Display,                    // The display itself
+    Result as DRes              // The associated result
+};
+
+use super::{                    // Using parts from the crate
+    cylindrical::Cylindrical,   // Cylindrical coordinates
+    spherical::Spherical        // Spherical coordinates
+};
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -69,8 +74,12 @@ impl Cartesian {
     /// assert_eq!(m, n);
     /// assert_eq!(n, d);
     /// ```
-    pub fn new() -> Self {
-        Self::default()
+    pub const fn new() -> Self {
+        Self {
+            x: 0.0,
+            y: 0.0,
+            z: 0.0
+        }
     }
 
     /// # From each point
@@ -93,6 +102,28 @@ impl Cartesian {
         }
     }
 
+    /// # From another coordinate system
+    /// 
+    /// Creates an Cartesian struct from another coordinate system. Calls the `Into<Cartesian>` method,
+    /// which is verified in its implementation.
+    /// 
+    /// ```
+    /// # use scilib::coordinate::cartesian::Cartesian;
+    /// # use scilib::coordinate::spherical::Spherical;
+    /// # use scilib::coordinate::cylindrical::Cylindrical;
+    /// let s: Spherical = Spherical::from(2.4, 65, 15);
+    /// let c: Cylindrical = Cylindrical::from_degree(1.2, 32, -3);
+    /// let res1: Cartesian = Cartesian::from_coord(s);
+    /// let res2: Cartesian = Cartesian::from_coord(c);
+    /// 
+    /// assert_eq!(res1, s.into());
+    /// assert_eq!(res2, c.into());
+    /// ```
+    pub fn from_coord<T>(c: T) -> Self
+    where T: Into<Self> {
+        c.into()
+    }
+
     /// # Computes the vector norm
     /// 
     /// We follow the convention of the l2 norm in this implementation.
@@ -217,6 +248,43 @@ impl Into<Spherical> for Cartesian {
     }
 }
 
+/// # Conversion to cylindrical coordinates
+/// 
+/// ```
+/// # use std::f64::consts::SQRT_2;
+/// # use scilib::coordinate::cylindrical::Cylindrical;
+/// # use scilib::coordinate::cartesian::Cartesian;
+/// 
+/// let s = Cartesian::from(1, 1, 1.2);
+/// let conv: Cylindrical = s.into();
+/// let expected = Cylindrical::from_degree(SQRT_2, 45, 1.2);
+/// 
+/// assert_eq!(conv, expected);
+/// 
+/// let s = Cartesian::from(1, 0, 1);
+/// let conv: Cylindrical = s.into();
+/// let expected = Cylindrical::from_degree(1.0, 0, 1.0);
+/// 
+/// assert_eq!(conv, expected);
+/// ```
+impl Into<Cylindrical> for Cartesian {
+    fn into(self) -> Cylindrical {
+        let rho: f64 = (self.x.powi(2) + self.y.powi(2)).sqrt();
+        let mut nt: f64 = (self.y / self.x).atan();
+
+        // If we were in the wrong quadrants, the atan range doesn't work
+        if self.x.is_sign_negative() {
+            nt += PI;
+        }
+
+        Cylindrical {
+            r: rho,
+            theta: nt,
+            z: self.z
+        }
+    }
+}
+
 /// # Addition
 /// 
 /// ```
