@@ -30,18 +30,19 @@ const STIELTJES_M: usize = 1_000_000;
 
 /// # Sinus cardinal
 /// 
+/// ## Definition
 /// The value of the [cardinal sinus](https://fr.wikipedia.org/wiki/Sinus_cardinal) is defined as:
 /// $$
 /// \mathrm{sinc}(x) = \frac{\sin(x)}{x}
 /// $$
 /// By convention, when $x = 0,~\mathrm{sinc}(x) = 1$.
 /// 
-/// ---
-///
-/// `x`: the value at which to evaluate the function ($x$).
+/// ## Inputs
+/// - `x`: the value at which to evaluate the function ($x$).
 /// 
 /// Returns the sinc value of `x`.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::sinc;
 /// let x: f64 = sinc(0.0);
@@ -61,31 +62,29 @@ pub fn sinc(x: f64) -> f64 {
 
 /// # Binomial theorem
 /// 
+/// ## Definition
 /// The [binomial theorem](https://en.wikipedia.org/wiki/Binomial_theorem) is defined as:
 /// $$
 /// \binom{n}{k} = \frac{n!}{k!(n - k)!}
 /// $$
 /// 
-/// ---
-///
-/// `n` is the number of options ($n$) and `k` is the selection ($k$).
-/// 
-/// Returns `k` among `n`.
-/// 
-/// ```
-/// # use scilib::math::basic::binomial;
-/// let res: usize = binomial(4_usize, 2_usize);
-/// 
-/// assert_eq!(res, 6);
-/// ```
-/// 
-/// ---
-/// 
 /// The implementation used here relies on the recurrence relation:
 /// $$
 /// \binom{n}{k} = \binom{n-1}{k} + \binom{n-1}{k-1}
 /// $$
 /// This pushes overflow back for a few more terms.
+/// 
+/// ## Inputs
+/// - `n`: the number of options ($n$) and `k` is the selection ($k$).
+/// 
+/// Returns `k` among `n`.
+/// 
+/// ## Example
+/// ```
+/// # use scilib::math::basic::binomial;
+/// let res: usize = binomial(4_usize, 2_usize);
+/// assert_eq!(res, 6);
+/// ```
 pub fn binomial(n: usize, k: usize) -> usize {
 
     // n must be greater than k to produce a value
@@ -108,21 +107,22 @@ pub fn binomial(n: usize, k: usize) -> usize {
 }
 
 /// # Factorial function
+/// 
+/// ## Definition
 /// The [factorial function](https://en.wikipedia.org/wiki/Factorial) is defined as:
 /// $$
 /// n! = \prod_{i=1}^{n}i
 /// $$
 /// 
-/// ---
-/// 
-/// `n` is the integer at which to evaluate the factorial ($n$).
+/// ## Inputs
+/// - `n`: the integer at which to evaluate the factorial ($n$).
 /// 
 /// Returns `n!`, the product of positive integers less or equal to `n`.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::factorial;
 /// let res: usize = factorial(5_usize);
-/// 
 /// assert_eq!(res, 120);
 /// ```
 pub fn factorial<T>(n: T) -> usize
@@ -132,18 +132,21 @@ where T: Into<usize> {
 
 /// # Stieltjes Gamma function
 /// 
+/// ## Definition
 /// Based on the Stieltjes coefficients, the [Stieltjes gamma function](https://en.wikipedia.org/wiki/Stieltjes_constants)
 /// computes associated values, based on the formula:
 /// $$
 /// \gamma_n(x) = \lim_{m \to \infty} \sum_{k=0}^m \left( \frac{\ln(k+x)^n}{k+x} - \frac{\ln(m+x)^{n+1}}{n+1} \right)
 /// $$
 /// 
-/// `n` is the order of the Stieltjes function to use.
-/// `a` is the value at which to compute the function.
+/// ## Inputs
+/// - `n`: the order of the Stieltjes function to use.
+/// - `a`: the value at which to compute the function.
 /// 
 /// Returns the value of Gamma_n(a). At the moment, the results are only valid for the first few
 /// orders, as the computation is very expansive. To get the basic Stieltjes coefficient, set `a=1`.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::stieltjes;
 /// let res1 = stieltjes(0, 1.0.into());
@@ -203,14 +206,20 @@ where T: Into<f64>, U: Into<Complex> {
 
 /// # Polylogarithm
 /// 
-/// The [polylogarithm](https://en.wikipedia.org/wiki/Polylogarithm) is defined by an infinite series:
+/// ## Definition
+/// The [polylogarithm](https://en.wikipedia.org/wiki/Polylogarithm) is defined by the infinite series:
 /// $$
 /// Li_s(z) = \sum_{k=1}^\infty \frac{z^k}{k^s}
 /// $$
 /// Because of these properties, the polylogarithm can be computed only for $|z|<= 1$.
 /// 
-/// `s` is the power of the divisor ($s$) and `z` is the computed value ($s$).
+/// ## Inputs
+/// - `s`: the power of the divisor ($s$)
+/// - `z` is the computed value ($z$).
 /// 
+/// Returns the value of the polylogarithm $Li_s(z)$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::basic::li;
@@ -251,6 +260,7 @@ pub fn li(s: f64, z: Complex) -> Complex {
 
 /// # Gamma function
 /// 
+/// ## Definition
 /// The [gamma function](https://en.wikipedia.org/wiki/Gamma_function) is a generalization of the factorial, and is defined as:
 /// $$
 /// \Gamma(z) = \int_{0}^{\infty}x^{z-1}\exp(-x)dx
@@ -261,22 +271,23 @@ pub fn li(s: f64, z: Complex) -> Complex {
 /// \Gamma(n) = (n-1)!
 /// $$
 /// 
-/// ---
+/// With the current computation scheme, we limit the precision of the computation in exchange for speed.
+/// Typical values are achieve within a `1.0e-5` margin of error. Changing the method to another one
+/// might grant some more speed and lower the error on the results.
 /// 
-/// `x` is the value to evaluate ($x$).
+/// ## Inputs
+/// - `x`: the value to evaluate ($x$).
 /// 
+/// Returns the value of the gamma function.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::gamma;
 /// let res_1: f64 = gamma(2.3);
 /// let res_2: f64 = gamma(-0.45);
-/// 
 /// assert!((res_1 - 1.16671190).abs() < 1.0e-5);
 /// assert!((res_2 - -3.591387).abs() < 1.0e-5);
 /// ```
-/// 
-/// With the current computation scheme, we limit the precision of the computation in exchange for speed.
-/// Typical values are achieve within a `1.0e-5` margin of error. Changing the method to another one
-/// might grant some more speed and lower the error on the results.
 pub fn gamma<T>(value: T) -> f64
 where T: Into<f64> {
 
@@ -311,37 +322,34 @@ where T: Into<f64> {
 }
 
 /// # Euler Beta function
+/// 
+/// ## Definition
 /// The [beta function](https://en.wikipedia.org/wiki/Beta_function) is an integral similar to the gamma function,
 /// and it is defined as:
 /// $$
 /// B(x,y) = B(y,x) = \int_{0}^{1}t^{x-1}(1-t)^{y-1}dt
 /// $$
 /// 
-/// ---
-/// 
-/// `x` and `y` are the points at which to evaluate the function ($x$, $y$).
-/// 
-/// The computation of the result is based on results from the gamma function. It is also possible to define
-/// it with infinite series (or products), which could have some advantages, I'll investigate this possibility later.
-/// 
-/// ```
-/// # use scilib::math::basic::beta;
-/// let res: f64 = beta(1, 1.1);
-/// let comp1: f64 = beta(3, 2);
-/// let comp2: f64 = beta(2, 3);
-/// 
-/// assert!((res - 0.909090).abs() < 1.0e-5);
-/// assert_eq!(comp1, comp2);
-/// ```
-/// 
-/// ---
-/// 
 /// The current implementation relies on the relation:
 /// $$
 /// B(x,y) = \frac{\Gamma(x)\Gamma(y)}{\Gamma(x+y)}
 /// $$
 /// Which is easier to manage, but could be slower and slightly less precise.
 /// Future updates will improve this function.
+/// 
+/// ## Inputs
+/// - `x` and `y` are the points at which to evaluate the function ($x$, $y$).
+/// 
+/// 
+/// ## Example
+/// ```
+/// # use scilib::math::basic::beta;
+/// let res: f64 = beta(1, 1.1);
+/// let comp1: f64 = beta(3, 2);
+/// let comp2: f64 = beta(2, 3);
+/// assert!((res - 0.909090).abs() < 1.0e-5);
+/// assert_eq!(comp1, comp2);
+/// ```
 pub fn beta<T, U>(x: T, y: U) -> f64
 where T: Into<f64> + Copy, U: Into<f64> + Copy {
 
@@ -353,23 +361,24 @@ where T: Into<f64> + Copy, U: Into<f64> + Copy {
 }
 
 /// # Sigmoid function
+/// 
+/// ## Definition
 /// The [sigmoid function](https://en.wikipedia.org/wiki/Sigmoid_function) is defined as:
 /// $$
 /// \sigma(x) = \frac{1}{1 + \exp(-x)} = 1 - \sigma(-x)
 /// $$
 /// 
-/// ---
-/// 
-/// `x` is the value at which to evaluate the function ($x$).
+/// ## Inputs
+/// - `x`: the value at which to evaluate the function ($x$).
 /// 
 /// Returns the value of the sigmoid function.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::sigmoid;
 /// let res1: f64 = sigmoid(-1.0);
 /// let res2: f64 = sigmoid(0.0);
 /// let res_comp: f64 = sigmoid(1.0);
-/// 
 /// assert!((res1 - 0.26894142136999).abs() < 1.0e-12);
 /// assert_eq!(res2, 0.5);
 /// assert_eq!(res1, 1.0 - res_comp);
@@ -379,22 +388,25 @@ pub fn sigmoid(x: f64) -> f64 {
 }
 
 /// # Gaussian function
+/// 
+/// ## Definition
 /// The [gaussian function](https://en.wikipedia.org/wiki/Gaussian_function) is defined as:
 /// $$
 /// g(x) = a\cdot\exp\left(-\frac{(b - x)^2}{2c^2}\right)
 /// $$
 /// 
-/// ---
+/// ## Inputs
+/// - `a`: the amplitude ($a$)
+/// - `b`: the center ($b$)
+/// - `c`: the standard deviation ($c$)
+/// - `x`: the value to evaluate ($x$).
 /// 
-/// `a` is the amplitude ($a$), `b` is the center ($b$), 
-/// `c` is the standard deviation ($c$),`x` is the value to evaluate ($x$).
-/// 
-/// Computes the value of the gaussian function with parameters a, b, c at x.
+/// Returns the value of the gaussian function with parameters $a$, $b$, $c$ at $x$.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::gaussian;
 /// let res1: f64 = gaussian(1.0, 2.0, 3.0, 0.0);
-/// 
 /// assert_eq!(res1, 0.8007374029168081);
 /// ```
 pub fn gaussian(a: f64, b: f64, c: f64, x: f64) -> f64 {
@@ -402,46 +414,54 @@ pub fn gaussian(a: f64, b: f64, c: f64, x: f64) -> f64 {
 }
 
 /// # Normalized gaussian function
+/// 
+/// ## Definition
 /// The [normalized gaussian function](https://en.wikipedia.org/wiki/Gaussian_function) is defined as:
 /// $$
 /// g(x) = \frac{1}{\sigma\sqrt{2\pi}}\cdot\exp\left( -\frac{(x - \mu)^2}{2\sigma^2} \right)
 /// $$
 /// 
-/// ---
+/// ## Inputs
+/// - `mu`: the expected value ($\mu$)
+/// - `sigma`: the variance ($\sigma$)
+/// - `x`: the value to evaluate ($x$)
 /// 
-/// `lambda` is the expected value ($\mu$), `sigma` is the variance ($\sigma$).
+/// Returns the value of the normalized gaussian function with parameters
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::gaussian_normed;
 /// let res: f64 = gaussian_normed(1.0, 2.0, 3.0);
-/// 
 /// assert!((res - 0.120985362259).abs() < 1e-12);
 /// ```
 pub fn gaussian_normed(mu: f64, sigma: f64, x: f64) -> f64 {
-    (1.0 / (sigma * (TAU.sqrt()))) * (-(x - mu).powi(2) / (2.0 * sigma.powi(2))).exp()
+    (1.0 / (sigma * TAU.sqrt())) * (-(x - mu).powi(2) / (2.0 * sigma.powi(2))).exp()
 }
 
 /// # Error function
+/// 
+/// ## Definition
 /// The [error function](https://en.wikipedia.org/wiki/Error_function) is defined as:
 /// $$
 /// \mathrm{erf}(z) = \frac{2}{\sqrt{\pi}}\int_{0}^{z}\exp(-t^2)dt
 /// $$
 /// 
-/// ---
-/// 
-/// `val` is the point at which to evaluate the function ($z$).
-/// 
 /// We define the error function for complex number.
 /// 
 /// WARNING: the erf function will soon become f64 only, moving the erf function for complex as a
 /// complex function directly.
 /// 
+/// ## Inputs
+/// - `val`: the point at which to evaluate the function ($z$)
+/// 
+/// Returns the error function value at $z$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::basic::erf;
 /// let r = erf(2.1);
 /// let c = erf(Complex::from(-0.1, 0.7));
-/// 
 /// assert!((r.re - 0.997021).abs() < 1.0e-5);
 /// assert!((c.re - -0.18297754).abs() < 1.0e-5 && (c.im - 0.92747498).abs() < 1.0e-5);
 /// ```
@@ -482,23 +502,24 @@ where T: Into<Complex> {
 }
 
 /// # Complementary error function
+/// 
+/// ## Definition
 /// The [complementary error function](https://en.wikipedia.org/wiki/Error_function) is defined as:
 /// $$
 /// \mathrm{erfc}(z) = 1 - \mathrm{erf}(z)
 /// $$
 /// 
-/// ---
+/// ## Inputs
+/// - `val`: the point at which to evaluate the function ($z$)
 /// 
-/// `val` is the point at which to evaluate the function ($z$).
-/// 
-/// This function simply returns the complement of the error function, that is `1 - erf(z)`.
+/// Returns the complement of the error function, `1 - erf(z)`.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::basic::erfc;
 /// let c = Complex::from(1.25, 0.3);
 /// let res = erfc(c);
-/// 
 /// assert!((res.re - 0.0505570).abs() < 1.0e-5 && (res.im - -0.0663174).abs() < 1.0e-5);
 /// ```
 pub fn erfc<T>(val: T) -> Complex
@@ -507,23 +528,24 @@ where T: Into<Complex> {
 }
 
 /// # Imaginary error function
+/// 
+/// ## Definition
 /// The [imaginary error function](https://en.wikipedia.org/wiki/Error_function) is defined as:
 /// $$
 /// \mathrm{erfi}(z) = -i\cdot\mathrm{erf}(iz)
 /// $$
 /// 
-/// ---
+/// ## Inputs
+/// - `val`: the point at which to evaluate the function ($z$)
 /// 
-/// `val` is the point at which to evaluate the function ($z$).
-/// 
-/// This function is defined as `-i * erf(i*z)`.
+/// Returns the imaginary error function, $-i\mathrm{erf}(iz)$.
 /// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::basic::erfi;
 /// let c = Complex::from(0.07, -1.1);
 /// let res = erfi(c);
-/// 
 /// assert!((res.re - 0.02349883).abs() < 1.0e-5 && (res.im - -0.88201955).abs() < 1.0e-5);
 /// ```
 pub fn erfi<T>(val: T) -> Complex
@@ -532,6 +554,8 @@ where T: Into<Complex> {
 }
 
 /// # Builds Pascal's triangle line
+/// 
+/// ## Definition
 /// We can obtain any given line of the [pascal triangle](https://en.wikipedia.org/wiki/Pascal%27s_triangle) by using
 /// the formula defined here:
 /// $$
@@ -539,18 +563,17 @@ where T: Into<Complex> {
 /// $$
 /// Where $e_n^k$ is the element of the $n^{th}$ line and $i^{th}$ position.
 /// 
-/// ---
-/// 
-/// `n` the index of the line in the triangle.
-/// 
-/// Returns the line of index `n`.
-/// 
 /// The first position of the triangle is number as line 0, the rest follows from there.
 /// 
+/// ## Inputs
+/// - `n`: the index of the line in the triangle.
+/// 
+/// Returns the line at index `n`.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::pascal_triangle;
 /// let l5: Vec<usize> = pascal_triangle(5);
-/// 
 /// assert_eq!(l5, vec![1, 5, 10, 10, 5, 1]);
 /// ```
 pub fn pascal_triangle(n: usize) -> Vec<usize> {
@@ -564,11 +587,22 @@ pub fn pascal_triangle(n: usize) -> Vec<usize> {
 }
 
 /// # Levi-Civita symbol
+/// 
+/// ## Definition
+/// $$
+/// \epsilon_{ijk...l}
+/// $$
 /// Computes the result of the $n$ dimensional Levi-Civita symbol. Returns 1 if the indexes are an even permutation
 /// and -1 if odd permutation. If there is any repetition it returns 0.
 /// 
 /// The function does not perform a check to ensure that all numbers are account for.
 /// 
+/// ## Inputs
+/// - `val`: the list of the indexes to evaluate
+/// 
+/// Returns the value of the Levi-Civita symbol.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::basic::levi_civita;
 /// let pos = levi_civita(vec![2, 3, 4, 5, 1]);
