@@ -9,9 +9,9 @@
 //! x^2\frac{d^2y}{dx^2} + x\frac{dy}{dx} + (x^2 - \alpha^2)y = 0
 //! $$
 //! 
-//! ## First kind: J
+//! ## First kind: $J_n$
 //! 
-//! The Jn(x) function is the simplest solution to Bessel's equation. The most generalized case is for
+//! The $J_n(x)$ function is the simplest solution to Bessel's equation. The most generalized case is for
 //! a real index `n` and a complex number `x`, which is possible with this crate. Additionally, two methods are
 //! provided for this equation, one for a integer order (named `j`) and one for a real order (named `jf`). The integer
 //! order one is limited but is faster than its counterpart. The real order function is slower, but can compute any
@@ -25,10 +25,10 @@
 //! let res_f = jf(c, 1.5);             // Would also work with 1.0
 //! ```
 //! 
-//! ## Second kind: Y
+//! ## Second kind: $Y_n$
 //! 
-//! Similar to the first kind, the Y equation are solution of Bessel's equation with a singularity at the origin.
-//! The Y function is itself based on the J function. The function is undefined for any integer order, in which
+//! Similar to the first kind, the $Y_n(x)$ equation are solution of Bessel's equation with a singularity at the origin.
+//! The $Y$ function is itself based on the $J$ function. The function is undefined for any integer order, in which
 //! case the limit has to be taken.
 //! 
 //! ```rust
@@ -39,10 +39,10 @@
 //! let res_i = y(c, 1);                // The function takes the limit in this case
 //! ```
 //! 
-//! ## Modified first kind: I
+//! ## Modified first kind: $I_n$
 //! 
-//! Also known as the hyperbolic Bessel function of the first kind. Its definition is similar to J, but lacks the
-//! alternating `(-1)^k` term in the sum.
+//! Also known as the hyperbolic Bessel function of the first kind. Its definition is similar to $J$, but lacks the
+//! alternating $(-1)^k$ term in the sum.
 //! 
 //! ```rust
 //! # use scilib::math::complex::Complex;
@@ -51,10 +51,10 @@
 //! let res = i(c, -1.2);
 //! ```
 //! 
-//! ## Modified second kind: K
+//! ## Modified second kind: $K_n$
 //! 
-//! Also known as the hyperbolic Bessel function of the second kind. Its definition is similar to Y, but lacks the
-//! `cos(n*pi)`, and is normalized by `pi/2`.
+//! Also known as the hyperbolic Bessel function of the second kind. Its definition is similar to $Y$, but lacks the
+//! $cos(n\pi)$, and is normalized by $\pi/2$.
 //! 
 //! ```rust
 //! # use scilib::math::complex::Complex;
@@ -63,7 +63,7 @@
 //! let res = k(c, 0);
 //! ```
 //! 
-//! ## Hankel functions: H1 and H2
+//! ## Hankel functions: $H_n^{(1)}$ and $H_n^{(2)}$
 //! 
 //! Hankel functions are two linearly independent solutions to Bessel's equation.
 //! 
@@ -77,6 +77,103 @@
 //! 
 //! # Spherical Bessel functions
 //! 
+//! The spherical Bessel functions are used to solve the Helmholtz equation, which is:
+//! $$
+//! x^2\frac{d^2y}{dx^2} + 2x\frac{dy}{dx} + (x^2 - n(n+1))y = 0
+//! $$
+//! 
+//! There is two kinds of spherical Bessel functions, plus the corresponding Hankel functions
+//! 
+//! ## First kind: $j_n$
+//! First solution to the equation, the result is based on the $J_n$ Bessel equation.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::{ sj, sj_array };
+//! let c = Complex::from(1.44, 2.22);
+//! let res = sj(c, 2);         // Computes the single term
+//! let res_a = sj_array(c, 2); // Computes all term up to 2
+//! ```
+//! 
+//! ## Second kind: $y_n$
+//! Second solution to the equation, the result of this one is based on the $Y_n$ Bessel function.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::{ sy, sy_array };
+//! let c = Complex::from(2.53, -0.33);
+//! let res = sy(c, 2);         // Computes the single term
+//! let res_a = sy_array(c, 5); // Computes all term up to 5
+//! ```
+//! 
+//! ## Hankel first kind: $h^{(1)}$
+//! Follows the same definition as $H^{(1)}$, but using the spherical version of the Bessel equations.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::{ sh_first, sh_first_array };
+//! let c = Complex::from(0.2253, 4.25);
+//! let res = sh_first(c, 2);           // Computes the single term
+//! let res_a = sh_first_array(c, 4);   // Computes all term up to 5
+//! ```
+//! 
+//! ## Hankel second kind: $h^{(2)}$
+//! Follows the same definition as $H^{(2)}$, but using the spherical version of the Bessel equations.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::{ sh_second, sh_second_array };
+//! let c = Complex::from(-5.2, -0.356);
+//! let res = sh_second(c, 2);          // Computes the single term
+//! let res_a = sh_second_array(c, 7);  // Computes all term up to 7
+//! ```
+//! 
+//! # Riccati-Bessel functions
+//! 
+//! The Riccati-Bessel functions are modified Bessel functions, and are solutions to the equation:
+//! $$
+//! x^2\frac{d^2y}{dx^2} + (x^2 - n(n + 1))y = 0
+//! $$
+//! 
+//! ## First kind: $S_n$
+//! Simplest solution to the differential equation, we base the computation off of $J_n(x)$.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::riccati_s;
+//! let c = Complex::from(0.3, 1.22);
+//! let res = riccati_s(c, 2);
+//! ```
+//! 
+//! ## Second kind: $C_n$
+//! Similar to $S_n$, but is based on the $Y_n(x)$ Bessel function.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::riccati_c;
+//! let c = Complex::from(-4.2, 2.13);
+//! let res = riccati_c(c, 5);
+//! ```
+//! 
+//! ## Third kind: $\xi_n$
+//! This solution makes use of the first kind of Hankel function $H^{(1)}$.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::riccati_xi;
+//! let c = Complex::from(2.5, -0.25);
+//! let res = riccati_xi(c, 4);
+//! ```
+//! 
+//! ## Fourth kind: $\zeta_n$
+//! This last solution makes use of the second kind of Hankel function $H^{(2)}$.
+//! 
+//! ```rust
+//! # use scilib::math::complex::Complex;
+//! # use scilib::math::bessel::riccati_zeta;
+//! let c = Complex::from(-1.1, 8.2);
+//! let res = riccati_zeta(c, 3);
+//! ```
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -101,9 +198,8 @@ const DISTANCE_Y_LIM: f64 = 0.001;
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /// # $J$ Bessel function, integer index
-///
-/// `x` is the value to evaluate, and `n` the order of the function.
 /// 
+/// ## Definition
 /// The $J$ Bessel represent the first kind of Bessel function, and are solution to Bessel differential equation,
 /// and is defined as follows:
 /// $$
@@ -113,7 +209,14 @@ const DISTANCE_Y_LIM: f64 = 0.001;
 /// The bessel function depend on an infinite sum of terms; which we can't have.
 /// The criterion chosen here is check each new term impacts the results significantly enough.
 /// The default value selected in the program is defined by `const PRECISION_CONVERGENCE: f64 = 1.0e-8;`.
+///
+/// ## Inputs
+/// - `x`: the value to evaluate ($x$)
+/// - `n`: the order of the function ($n$)
 /// 
+/// Returns the value of the $n^{th}$ order of the Bessel $J$ function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::j;
@@ -189,9 +292,8 @@ pub fn j<T: Into<Complex>>(x: T, n: i32) -> Complex {
 }
 
 /// # $J$ Bessel function, real index
-///
-/// `x` is the value to evaluate, and `n` the order of the function.
 /// 
+/// ## Definition
 /// $$
 /// J_\alpha(x) = \sum_{m=0}^{\infty}\frac{(-1)^m}{m!\Gamma(m+\alpha+1)}\left( \frac{x}{2} \right)^{2p+\alpha}
 /// $$
@@ -200,7 +302,14 @@ pub fn j<T: Into<Complex>>(x: T, n: i32) -> Complex {
 /// than an integer. This method is more costly to use than the other, and thus isn't recommended for
 /// integer orders. The function tries to prevent this by trying to fall back on the integer order version
 /// when possible, but could fail in edge cases.
+///
+/// ## Inputs
+/// - `x`: the value to evaluate ($x$)
+/// - `order`: order of the function ($\alpha$)
 /// 
+/// Returns the value of the real order of the Bessel $J$ function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::{ j, jf };
@@ -273,18 +382,24 @@ pub fn jf<T, U>(x: T, order: U) -> Complex
 
 /// # Y Bessel function, real index
 /// 
+/// ## Definition
 /// The $Y$ Bessel represent the second kind of Bessel function, and are solution to Bessel differential equation,
 /// in the case of a singularity at the origin. It is defined as:
 /// $$
 /// Y_\alpha(x) = \frac{J_\alpha(x)\cos(\alpha\pi) - J_\alpha(x)}{\sin(\alpha\pi)}
 /// $$
 /// 
-/// `x` is the value to evaluate, and `n` the order of the function.
-/// 
 /// Because the function is not continuous for integer values of `n`, we need to compute the limit around these points.
 /// We set the limit distance with `DISTANCE_Y_LIM`, compute the limit above and below the desired point and take the average.
 /// We achieve precision under `1.0e-5` for non-integer`n`, and integer `n` using this approach.
 /// 
+/// ## Inputs
+/// - `x`: the value to evaluate ($x$)
+/// - `order`: the order of the function ($\alpha$)
+/// 
+/// Returns the value of the real order of the Bessel $Y$ function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::y;
@@ -326,16 +441,22 @@ where T: Into<Complex> + Copy, U: Into<f64> {
 
 /// # $I$ modified Bessel function
 /// 
+/// ## Definition
 /// The $I$ modified First Bessel function represent another kind of solution to the Bessel differential equation.
 /// 
-/// `x` is the value to evaluate, and `n` the order of the function.
-/// 
 /// We use a definition of I based on an infinite series (similar to $J$). This way, we ensure good precision in
 /// the computation, by following the definition:
 /// $$
 /// I_\alpha = i^{-\alpha}J_\alpha(ix)=\sum_{m=0}^{\infty}\frac{1}{m!\Gamma(m+\alpha+1)}\left( \frac{x}{2} \right)^{2m+\alpha}
 /// $$
 /// 
+/// ## Inputs
+/// - `x` is the value to evaluate ($x$)
+/// - `order` the order of the function ($\alpha$)
+/// 
+/// Returns the value of the real order of the Bessel $I$ function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::{i, jf};
@@ -391,15 +512,21 @@ where T: Into<Complex>, U: Into<f64> + Copy {
 
 /// # $K$ modified Bessel function
 /// 
+/// ## Definition
 /// The $K$ modified Second Bessel function represent another kind of solution to the Bessel differential equation.
 /// 
-/// `x` is the value to evaluate, and `n` the order of the function.
-/// 
 /// The definition of $K$ is similar to $Y$, but is based on $I$ and not $J$:
 /// $$
 /// K_\alpha(x) = \frac{\pi}{2}\frac{I_{-\alpha}(x) - I_\alpha(x)}{\sin(\alpha\pi)}
 /// $$
 /// 
+/// ## Inputs
+/// - `x` is the value to evaluate ($x$)
+/// - `order` the order of the function ($\alpha$)
+/// 
+/// Returns the value of the real order of the Bessel $K$ function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::k;
@@ -425,13 +552,21 @@ where T: Into<Complex> + Copy, U: Into<f64> {
     }
 }
 
-/// # First Hankel function: H1
+/// # First Hankel function: $H^{(1)}$
 /// 
+/// ## Definition
 /// Computes the first kind of Hankel function, which is defined as:
 /// $$
 /// H_\alpha^{(1)}(x) = J_\alpha(x) + iY_\alpha(x)
 /// $$
 /// 
+/// ## Inputs
+/// - `x` is the value to evaluate ($x$)
+/// - `order` the order of the function ($\alpha$)
+/// 
+/// Returns the value of the real order of the first hankel function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::hankel_first;
@@ -453,13 +588,21 @@ where T: Into<Complex> + Copy, U: Into<f64> {
     res_j + res_y
 }
 
-/// # Second Hankel function: H2
+/// # Second Hankel function: $H^{(2)}$
 /// 
+/// ## Definition
 /// Computes the first kind of Hankel function, which is defined as:
 /// $$
 /// H_\alpha^{(2)}(x) = J_\alpha(x) - iY_\alpha(x)
 /// $$
 /// 
+/// ## Inputs
+/// - `x` is the value to evaluate ($x$)
+/// - `order` the order of the function ($\alpha$)
+/// 
+/// Returns the value of the real order of the second hankel function at $x$.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::hankel_second;
@@ -484,15 +627,19 @@ where T: Into<Complex> + Copy, U: Into<f64> {
 
 /// # First spherical Bessel function: $j$
 /// 
+/// ## Definition
 /// We follow the definition based on the $J$ Bessel functions:
 /// $$
 /// j_n(x) = \sqrt{\frac{\pi}{2x}}J_{n+\frac{1}{2}}(x)
 /// $$
 /// 
-/// Compute the first kind of spherical bessel function.
-/// * `z` - where the function is evaluated
-/// * `n` - order evaluated
+/// ## Inputs
+/// - `z`: where the function is evaluated ($x$)
+/// - `n`: order evaluated ($n$)
 /// 
+/// Returns the first kind of spherical bessel function.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -542,10 +689,14 @@ where T: Into<Complex> {
 
 /// # First spherical Bessel function (array): j
 /// 
+/// ## Inputs
 /// Computes the first kind of spherical bessel function by recurrence to get an array of function.
-/// * `z` - where the function is evaluated
-/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sj[0]` to `sj[n]`
+/// - `z`: where the function is evaluated
+/// - `n`: maximum order evaluated
 /// 
+/// Returns a vector from 0 to the nth order included : `sj[0]` to `sj[n]`.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -607,15 +758,19 @@ where T: Into<Complex> {
 
 /// # Second spherical Bessel function: $y$
 /// 
+/// ## Definition
 /// We follow the definition based on the $Y$ Bessel functions:
 /// $$
 /// y_n(x) = \sqrt{\frac{\pi}{2x}}Y_{n+\frac{1}{2}}(x)
 /// $$
 /// 
-/// Compute the second kind of spherical bessel function.
-/// * `z` - where the function is evaluated
-/// * `n` - order evaluated
+/// ## Inputs
+/// - `z`: where the function is evaluated
+/// - `n`: order evaluated
 /// 
+/// Returns the second kind of spherical bessel function.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -630,10 +785,14 @@ where T: Into<Complex> {
 
 /// # Second spherical Bessel function (array): y
 /// 
+/// ## Inputs
 /// Computes the second kind of spherical bessel function by recurrence to get an array of function.
-/// * `z` - where the function is evaluated
-/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sy[0]` to `sy[n]`
+/// - `z`: where the function is evaluated
+/// - `n`: maximum order evaluated
 /// 
+/// Returns a vector from 0 to the nth order included : `sy[0]` to `sy[n]`.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -681,17 +840,20 @@ where T: Into<Complex> {
     yn
 }
 
-/// # First spherical Hankel function: h1
+/// # First spherical Hankel function: $h^{(1)}$
 /// 
+/// ## Definition
 /// The first spherical hankel function is defined as:
 /// $$
 /// h_n^{(1)}(x) = j_n(x) + iy_n(x)
 /// $$
 /// 
+/// ## Inputs
 /// Compute the first kind of spherical hankel function.
-/// * `z` - where the function is evaluated
-/// * `n` - order evaluated
+/// - `z`: where the function is evaluated ($x$)
+/// - `n`: order evaluated ($n$)
 /// 
+/// # Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -704,12 +866,16 @@ where T: Into<Complex> {
     sj(x, n) + Complex::i() * sy(x, n)
 }
 
-/// # First spherical Hankel function (array): h1
+/// # First spherical Hankel function (array): $h^{(1)}$
 /// 
+/// ## Inputs
 /// Compute the first kind of spherical hankel function by recurrence to get an array of function.
-/// * `z` - where the function is evaluated
-/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sh_first[0]` to `sh_first[n]`
+/// - `z`: where the function is evaluated
+/// - `n`: maximum order evaluated
 /// 
+/// Returns a vector from 0 to the nth order included : `sh_first[0]` to `sh_first[n]`.
+/// 
+/// # Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -738,17 +904,21 @@ where T: Into<Complex> {
     sh_first
 }
 
-/// # Second spherical Hankel function: h2
+/// # Second spherical Hankel function: $h^{(2)}$
 /// 
+/// ## Definition
 /// The second spherical hankel function is defined as:
 /// $$
 /// h_n^{(2)}(x) = j_n(x) - iy_n(x)
 /// $$
 /// 
-/// Compute the second kind of spherical hankel function.
-/// * `z` - where the function is evaluated
-/// * `n` - order evaluated
+/// ## Inputs
+/// - `z`: where the function is evaluated ($x$)
+/// - `n`: order evaluated ($n$)
 /// 
+/// Returns the second kind of spherical hankel function.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -761,12 +931,16 @@ where T: Into<Complex> {
     sj(x, n) - Complex::i() * sy(x, n)
 }
 
-/// # Second spherical Hankel function (array): h2
+/// # Second spherical Hankel function (array): $h^{(2)}$
 /// 
+/// ## Inputs
 /// Compute the second kind of spherical hankel function by recurrence to get an array of function.
-/// * `z` - where the function is evaluated
-/// * `n` - maximum order evaluated, return a vector from 0 to the nth order included : `sh_second[0]` to `sh_second[n]`
+/// - `z`: where the function is evaluated
+/// - `n`: maximum order evaluated
 /// 
+/// Returns a vector from 0 to the nth order included : `sh_second[0]` to `sh_second[n]`.
+/// 
+/// ## Example
 /// ```
 /// # use scilib::math::complex::Complex;
 /// # use scilib::math::bessel::*;
@@ -796,3 +970,85 @@ where T: Into<Complex> {
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+/// # Riccati-Bessel function $S_n$
+/// ## Definition
+/// The $S_n$ Riccati-Bessel function is defined as:
+/// $$
+/// S_n(z) = \sqrt{\frac{\pi z}{2}}J_{n+\frac{1}{2}}(z)
+/// $$
+/// Where $J_{n+\frac{1}{2}}(z)$ is the Bessel function of the first kind.
+/// 
+/// ## Inputs
+/// - `z` is the value to evaluate ($x$)
+/// - `n` the order of the function ($n$)
+/// 
+/// ## Example
+pub fn riccati_s<T>(x: T, n: usize) -> Complex
+where T: Into<Complex>{
+
+    let z: Complex = x.into();
+    (FRAC_PI_2 * z).sqrt() * jf(z, n as f64 + 0.5)
+}
+
+/// # Riccati-Bessel function $C_n$
+/// ## Definition
+/// The $C_n$ Riccati-Bessel function is defined as:
+/// $$
+/// C_n(z) = -\sqrt{\frac{\pi z}{2}}Y_{n+\frac{1}{2}}(z)
+/// $$
+/// Where $Y_{n+\frac{1}{2}}(z)$ is the Bessel function of the second kind.
+/// 
+/// ## Inputs
+/// - `z` is the value to evaluate ($x$)
+/// - `n` the order of the function ($n$)
+/// 
+/// ## Example
+pub fn riccati_c<T>(x: T, n: usize) -> Complex
+where T: Into<Complex>{
+    
+    let z: Complex = x.into();
+    -(FRAC_PI_2 * z).sqrt() * y(z, n as f64 + 0.5)
+}
+
+/// # Riccati-Bessel function $\xi_n$
+/// ## Definition
+/// The $\xi_n$ Riccati-Bessel function is defined as:
+/// $$
+/// \xi_n(z) = \sqrt{\frac{\pi z}{2}}H_{n+\frac{1}{2}}^{(1)}(z)
+/// $$
+/// Where $H_{n+\frac{1}{2}}^{(1)}(z)$ is the Hankel function of the first kind.
+/// 
+/// ## Inputs
+/// - `z` is the value to evaluate ($x$)
+/// - `n` the order of the function ($n$)
+/// 
+/// ## Example
+pub fn riccati_xi<T>(x: T, n: usize) -> Complex
+where T: Into<Complex>{
+    
+    let z: Complex = x.into();
+    (FRAC_PI_2 * z).sqrt() * hankel_first(z, n as f64 + 0.5)
+}
+
+/// # Riccati-Bessel function $\zeta_n$
+/// ## Definition
+/// The $\zeta_n$ Riccati-Bessel function is defined as:
+/// $$
+/// \zeta_n(z) = \sqrt{\frac{\pi z}{2}}H_{n+\frac{1}{2}}^{(2)}(z)
+/// $$
+/// Where $H_{n+\frac{1}{2}}^{(2)}(z)$ is the Hankel function of the first kind.
+/// 
+/// ## Inputs
+/// - `z` is the value to evaluate ($x$)
+/// - `n` the order of the function ($n$)
+/// 
+/// ## Example
+pub fn riccati_zeta<T>(x: T, n: usize) -> Complex
+where T: Into<Complex>{
+    
+    let z: Complex = x.into();
+    (FRAC_PI_2 * z).sqrt() * hankel_second(z, n as f64 + 0.5)
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
